"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const virtual_core_1 = require("virtual-core");
const ProjectDirectoryUtils_1 = require("./ProjectDirectoryUtils");
class SlotTypesBuilder {
    static fromDirectory(directory) {
        ProjectDirectoryUtils_1.validateProjectDirectory(directory);
        const { entities, entitiesEntries } = ProjectDirectoryUtils_1.getEntitiesDirectoryFiles(directory);
        const slotTypeArray = entities.map((entity) => {
            const entityName = entity.replace(".json", "");
            return SlotTypesBuilder.getSlotFromJsonFile(directory, entityName, entitiesEntries);
        });
        return new virtual_core_1.SlotTypes(slotTypeArray);
    }
    static getSlotFromJsonFile(directory, entity, entitiesEntries) {
        const entriesForEntity = entitiesEntries.filter((entry) => entry.includes(entity));
        const slotValuesForEntity = entriesForEntity.reduce((slotValues, entry) => {
            const fileData = fs.readFileSync(path.join(directory, ProjectDirectoryUtils_1.ENTITIES_DIRECTORY, entry));
            const slotValueNames = JSON.parse(fileData.toString());
            const slotValuesFromEntry = slotValueNames.map((slotValueName) => {
                return {
                    name: slotValueName,
                };
            });
            return slotValues.concat(slotValuesFromEntry);
        }, []);
        return new virtual_core_1.SlotType(entity, slotValuesForEntity);
    }
}
exports.SlotTypesBuilder = SlotTypesBuilder;
//# sourceMappingURL=SlotTypesBuilder.js.map